SamsaRaLight-package: SamsaRaLight: Forest light interception and radiation...

SamsaRaLight-packageR Documentation

SamsaRaLight: Forest light interception and radiation simulation

Description

SamsaRaLight is an R package for simulating forest stand light interception, energy balance and radiation transfer using spatially explicit tree crowns, sensors and grid cells.

Details

The package provides tools to:

  • Build forest stands with trees, cells and sensors

  • Run ray-tracing based light simulations

  • Compute tree, cell and sensor energy variables

  • Summarize and visualize simulation outputs

Author(s)

Maintainer: Natheo Beauchamp beauchamp.natheo@gmail.com (ORCID) (R package developer)

Authors:

See Also

Useful links:


SamsaRaLight documentation built on April 16, 2026, 5:08 p.m.