View source: R/get_monthly_radiations.R
| get_monthly_radiations | R Documentation |
Fetch monthly radiation data from PVGIS website (by API) between start and end year (limit years are from 2005 to 2020). Fetched variables are Hrad = horizontal plane irradiation and DGratio = ratio of diffuse to global radiation (in horizontal plane).
! YOU NEED AN INTERNET CONNECTION TO ACCESS THE DATA BY API !
get_monthly_radiations(latitude, longitude, start_year = 2005, end_year = 2020)
latitude |
latitude of the plot |
longitude |
longitude of the plot |
start_year |
positive integer between 2005 and 2020 - start year on which to fetch monthly data |
end_year |
positive integer between 2005 and 2020 - end year on which to fetch monthly data |
Monthly horizontal radiation (Hrad) and diffuse to global ratio (DGratio) averaged between start_year and end_year
https://joint-research-centre.ec.europa.eu/pvgis-photovoltaic-geographical-information-system_en
# Example: fetch monthly radiation somewhere in Belgium
rad <- get_monthly_radiations(
latitude = 50.85,
longitude = 4.35,
start_year = 2010,
end_year = 2015
)
head(rad)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.