View source: R/plot.sl_stand.R
| plot.sl_stand | R Documentation |
This function plots a virtual forest stand (sl_stand) produced by SamsaRaLight.
It can display a top-down view with tree crowns or a side/top view with cells and trees.
## S3 method for class 'sl_stand'
plot(x, ..., top_down = FALSE, only_inv = FALSE, add_sensors = TRUE)
x |
An object of class |
... |
Additional arguments passed to lower-level plotting functions. |
top_down |
Logical, if TRUE, creates a top-down view with multiple directions (south, north, west, east). |
only_inv |
Logical, if TRUE, plot only trees from the initial inventory (i.e. not trees added to fill around the core polygon) |
add_sensors |
Logical; if TRUE (default), sensors are drawn on the plot. In top-down mode, sensors are shown as segment from ground to their height; in map view, sensors are drawn as squares on the ground. |
For the sake of the representation in top-down plot, z are offset such as minimum altitude tree is at Y-axis height = 0
The plot function also generates a compass indicating:
Plot orientation (north2x, north in red)
Terrain aspect (downslope direction)
Slope degrees (annotation only)
A ggplot object representing the stand.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.