Visualizes a forest inventory as ellipses representing tree crowns.
Arguments
- trees_inv
A data.frame of trees that passed check_inventory.
- core_polygon_df
Optional data.frame defining the core inventory polygon. Must contain columns
xandy.- show_id
Logical; if TRUE (default), displays tree identifiers at crown centers.
Details
Because the north2x variable is unknown, trees are plotted as circles by considering the mean radius on the four cardinals.
Examples
data_prenovel <- SamsaRaLight::data_prenovel
trees_inv <- data_prenovel$trees
plot_inventory(trees_inv)