plot_slope_profile: Plot a slope profile indicator

View source: R/plot.sl_stand.R

plot_slope_profileR Documentation

Plot a slope profile indicator

Description

This function draws a small schematic profile representing terrain slope as an inclined line relative to a horizontal reference.

Usage

plot_slope_profile(slope, size = 1)

Arguments

slope

Numeric. Slope angle in degrees. If NA or 0, only the horizontal reference is shown.

size

Numeric. Scaling factor controlling the size of the graphic (default = 1).

Details

It is intended to be used as a companion graphic to stand orientation plots (e.g. compass), for visualizing slope magnitude.

Value

A ggplot2 object representing the slope profile.


SamsaRaLight documentation built on April 16, 2026, 5:08 p.m.