Prints a compact, human-readable, one-line description of a
sl_stand object, summarizing the stand size, number of trees,
number of sensors, and grid geometry.
Usage
# S3 method for class 'sl_stand'
print(x, ...)Prints a compact, human-readable, one-line description of a
sl_stand object, summarizing the stand size, number of trees,
number of sensors, and grid geometry.
# S3 method for class 'sl_stand'
print(x, ...)