| SamsaRaLight-package | R Documentation |
SamsaRaLight is an R package for simulating forest stand light interception, energy balance and radiation transfer using spatially explicit tree crowns, sensors and grid cells.
The package provides tools to:
Build forest stands with trees, cells and sensors
Run ray-tracing based light simulations
Compute tree, cell and sensor energy variables
Summarize and visualize simulation outputs
Maintainer: Natheo Beauchamp beauchamp.natheo@gmail.com (ORCID) (R package developer)
Authors:
Gauthier Ligot gligot@uliege.be (ORCID) (Java Capsis developer and algorithm improvement)
Francois de Coligny francois.decoligny@inrae.fr (ORCID) (Java Capsis developer)
Maxime Jaunatre maxime.jaunatre@inrae.fr (ORCID) (R package support developer)
Benoit Courbaud benoit.courbaud@inrae.fr (ORCID) (Algorithm and theory creator) [copyright holder]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.