| SamsaRaLight_data | R Documentation |
These datasets provide example forest inventories used for light interception
simulations with the SamsaRaLight package. Each dataset is a named list
with 5 elements: trees, sensors, core_polygon, radiations, and info.
data(data_prenovel)
data(data_IRRES1)
data(data_bechefa)
data(data_cloture20)
data_prenovel
data_IRRES1
data_bechefa
data_cloture20
A named list with 5 elements:
A data.frame with tree-level data:
Unique id of the tree (integer).
Latin species name (character).
Coordinates of the base of the tree in meters (numeric).
Diameter at breast height in cm (numeric).
Crown shape type, e.g. "P", "E", or complex types like "8E" (character).
Height of the tree trunk in meters (numeric).
Height of crown base in meters (numeric).
Height at which crown radius is maximum, NA if not used (numeric).
Crown radii in meters (numeric).
Leaf area density of the crown (m2/m3) (numeric).
A data.frame with sensor data:
Unique sensor ID (integer).
Coordinates of the sensor in meters (numeric).
Height of the sensor in meters (numeric).
Proportion of above-canopy light measured at the sensor (numeric).
May be NULL if no sensors are present.
A data.frame with vertices of the inventory polygon:
Coordinates of polygon vertices in meters (numeric).
A data.frame of monthly radiation:
Month number (integer).
Monthly radiation in MJ (numeric).
Diffuse-to-global radiation ratio (numeric).
A named list with site information:
Coordinates of the site in decimal degrees (numeric).
Mean slope in degrees (numeric).
Aspect in degrees from north (numeric).
Angle from north to x-axis clockwise in degrees (numeric).
An object of class list of length 5.
An object of class list of length 5.
An object of class list of length 5.
An object of class list of length 5.
Courbaud Benoit (INRAe LESSEM Grenoble)
Gauthier Ligot (Gembloux Agro-Bio Tech)
Gauthier Ligot (Gembloux Agro-Bio Tech)
Gauthier Ligot (Gembloux Agro-Bio Tech)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.