| get_bottom_azimut | R Documentation |
Compute bottom azimut
get_bottom_azimut(aspect, north2x)
aspect |
double - Angle of slope bottom on the compass from the North, clockwise rotation (in degrees) northern aspect : 0, eastern aspect : 90, southern aspect : 180, western aspect : 270 |
north2x |
double - Angle from North to x axis clockwise. (in degrees) Default correspond to a Y axis oriented toward the North. |
a bottom azimuth numeric value
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.