View source: R/plot.sl_output.R
| plot.sl_output | R Documentation |
Visualize ground light and tree energy metrics for a sl_output object.
## S3 method for class 'sl_output'
plot(
x,
...,
what_trees = c("compet", "intercepted", "potential"),
what_cells = c("relative", "absolute"),
show_trees = TRUE,
direct_energy = NULL
)
x |
An object of class |
... |
Additional arguments passed to lower-level plotting functions. |
what_trees |
Character; which tree metric to plot. Choices are:
Default is "compet". |
what_cells |
Character; which cell (ground) metric to plot. Choices are:
Default is "relative". |
show_trees |
Logical; whether to display trees on top of the ground light map. Default is TRUE. |
direct_energy |
Logical or NULL.
If NULL (default), total radiation outputs are plotted (direct + diffuse).
If TRUE, only direct radiation components are plotted.
If FALSE, only diffuse radiation components are plotted.
This option requires |
A ggplot object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.