plot_inventory: Plot a from-above view of a tree inventory

View source: R/plot_inventory.R

plot_inventoryR Documentation

Plot a from-above view of a tree inventory

Description

Visualizes a forest inventory as ellipses representing tree crowns.

Usage

plot_inventory(trees_inv, core_polygon_df = NULL, show_id = TRUE)

Arguments

trees_inv

A data.frame of trees that passed check_inventory.

core_polygon_df

Optional data.frame defining the core inventory polygon. Must contain columns x and y.

show_id

Logical; if TRUE (default), displays tree identifiers at crown centers.

Details

Because the north2x variable is unknown, trees are plotted as circles by considering the mean radius on the four cardinals.

Value

A ggplot object displaying the trees in a from-above view.

Examples

data_prenovel <- SamsaRaLight::data_prenovel
trees_inv <- data_prenovel$trees

plot_inventory(trees_inv)


SamsaRaLight documentation built on April 16, 2026, 5:08 p.m.