View source: R/plot_inventory.R
| plot_inventory | R Documentation |
Visualizes a forest inventory as ellipses representing tree crowns.
plot_inventory(trees_inv, core_polygon_df = NULL, show_id = TRUE)
trees_inv |
A data.frame of trees that passed check_inventory. |
core_polygon_df |
Optional data.frame defining the core inventory polygon.
Must contain columns |
show_id |
Logical; if TRUE (default), displays tree identifiers at crown centers. |
Because the north2x variable is unknown, trees are plotted as circles by considering the mean radius on the four cardinals.
A ggplot object displaying the trees in a from-above view.
data_prenovel <- SamsaRaLight::data_prenovel
trees_inv <- data_prenovel$trees
plot_inventory(trees_inv)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.