View source: R/plot.sl_stand.R
| plot_slope_profile | R Documentation |
This function draws a small schematic profile representing terrain slope as an inclined line relative to a horizontal reference.
plot_slope_profile(slope, size = 1)
slope |
Numeric. Slope angle in degrees. If |
size |
Numeric. Scaling factor controlling the size of the graphic (default = 1). |
It is intended to be used as a companion graphic to stand orientation plots (e.g. compass), for visualizing slope magnitude.
A ggplot2 object representing the slope profile.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.