View source: R/print.sl_output.R
| print.sl_output | R Documentation |
sl_output objectPrints a concise one-line summary of a SamsaRaLight simulation result, reporting the number of cells, trees, and sensors, and whether detailed outputs are available.
## S3 method for class 'sl_output'
print(x, ...)
x |
An object of class |
... |
Further arguments passed to or from other methods (ignored). |
The object x, invisibly.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.