View source: R/create_sl_rays.R
| sl_create_rays_diffuse | R Documentation |
Create SamsaraLight diffuse rays of a plane with a classical sky hemisphere divided by meridians and parallels can use Standard Overcast Sky or Uniform Overcast Sky
sl_create_rays_diffuse(
soc,
total_diffuse,
height_anglemin_rad,
diffuse_anglestep_rad,
slope_rad,
bottom_azimut_rad
)
soc |
boolean - Standard Overcast Sky, if false: Uniform Overcast Sky |
total_diffuse |
double - Total diffuse energy on a horizontal plan (in kWh.m-2) |
height_anglemin_rad |
double - Angle minimum between beam and soil (in radians) |
diffuse_anglestep_rad |
double - Hour angle between two diffuse beams (in radians) |
slope_rad |
double - Slope of the plan (in radians) |
bottom_azimut_rad |
double - Azimut of the vector orthogonal to the ground in the (x,y) system (in radians) |
list of 3 elements : horizontal energy (double), slope energy (double) and diffuse rays (data.frame)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.